==> crisis-management-resources-v0.2-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/BusProviderImplementationManager.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import java.util.logging.Logger;
import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.xml.bind.annotation.XmlSeeAlso;
import fr.mines_albi.nuclearcrisisevent.provider.BusProvider;
import org.petalslink.easiestdemo.wsoui.provided.AbstractImplementationManager;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.wsoui.context.WSOUIJaxbContext;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;
import org.petalslink.easiestdemo.wsoui.provided.notification.SubscriptionManager;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.Subscribe;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.SubscribeResponse;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.refinedabstraction.RefinedWsnbFactory;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.utils.WsnbException;
import org.w3c.dom.Document;
import java.net.URL;
import java.util.Enumeration;
import com.ebmwebsourcing.easycommons.research.util.jaxb.SOAJAXBContext;
import java.lang.InterruptedException;
import java.net.URLClassLoader;
import java.util.ArrayList;
import java.util.List;
import java.io.File;
@javax.jws.WebService(
	wsdlLocation = "crisis/v3/./busProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	endpointInterface = "fr.mines_albi.nuclearcrisisevent.provider.BusProvider",
	portName = "busProviderPort",
	serviceName = "busProvider")
public class BusProviderImplementationManager extends AbstractImplementationManager<BusProvider> implements BusProvider{

	private AbstractEventProducerNotifier eventProducer = null;
	private WSOUIJaxbContextItf context = null;

	public BusProviderImplementationManager(AbstractTestImplementation ti, URL wsdl) throws WSOUIException {
		super(ti, wsdl);
		context = new WSOUIJaxbContext();
		this.eventProducer = new BusProvider_EventProducerNotifier(this.getConfiguration(), context);
	}

	public BusProviderImplementationManager(AbstractTestImplementation ti, URL wsdl, ProviderConfiguration configuration) throws WSOUIException {
		super(ti, wsdl, configuration);
		context = new WSOUIJaxbContext();
		this.eventProducer = new BusProvider_EventProducerNotifier(this.getConfiguration(), context);
	}

	public fr.mines_albi.nuclearcrisisevent.provider.ProvidebusDriverResponse providebusDriver(ProvidebusDriverRequest parameters)  {
		fr.mines_albi.nuclearcrisisevent.provider.ProvidebusDriverResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("providebusDriver" ,parameters);
		response = this.getTestImplementation().providebusDriver(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("busProvider", "busProviderPort", "providebusDriver", parameters, response, fr.mines_albi.nuclearcrisisevent.provider.ProvidebusDriverResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (fr.mines_albi.nuclearcrisisevent.provider.ProvidebusDriverResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("providebusDriver" ,parameters, response);
		return response;
	}


	public fr.mines_albi.nuclearcrisisevent.provider.ProvidebusResponse providebus(ProvidebusRequest parameters)  {
		fr.mines_albi.nuclearcrisisevent.provider.ProvidebusResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("providebus" ,parameters);
		response = this.getTestImplementation().providebus(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("busProvider", "busProviderPort", "providebus", parameters, response, fr.mines_albi.nuclearcrisisevent.provider.ProvidebusResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (fr.mines_albi.nuclearcrisisevent.provider.ProvidebusResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("providebus" ,parameters, response);
		return response;
	}



}

==> crisis-management-resources-v0.3-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/BusProviderImplementationManager.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import java.util.logging.Logger;
import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.xml.bind.annotation.XmlSeeAlso;
import fr.mines_albi.nuclearcrisisevent.provider.BusProvider;
import org.petalslink.easiestdemo.wsoui.provided.AbstractImplementationManager;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.wsoui.context.WSOUIJaxbContext;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;
import org.petalslink.easiestdemo.wsoui.provided.notification.SubscriptionManager;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.Subscribe;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.SubscribeResponse;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.refinedabstraction.RefinedWsnbFactory;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.utils.WsnbException;
import org.w3c.dom.Document;
import java.net.URL;
import java.util.Enumeration;
import com.ebmwebsourcing.easycommons.research.util.jaxb.SOAJAXBContext;
import java.lang.InterruptedException;
import java.net.URLClassLoader;
import java.util.ArrayList;
import java.util.List;
import java.io.File;
@javax.jws.WebService(
	wsdlLocation = "crisis/management/generated/./busProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	endpointInterface = "fr.mines_albi.nuclearcrisisevent.provider.BusProvider",
	portName = "busProviderPort",
	serviceName = "busProvider")
public class BusProviderImplementationManager extends AbstractImplementationManager<BusProvider> implements BusProvider{

	private AbstractEventProducerNotifier eventProducer = null;
	private WSOUIJaxbContextItf context = null;

	public BusProviderImplementationManager(AbstractTestImplementation ti, URL wsdl) throws WSOUIException {
		super(ti, wsdl);
		context = new WSOUIJaxbContext();
		this.eventProducer = new BusProvider_EventProducerNotifier(this.getConfiguration(), context);
	}

	public BusProviderImplementationManager(AbstractTestImplementation ti, URL wsdl, ProviderConfiguration configuration) throws WSOUIException {
		super(ti, wsdl, configuration);
		context = new WSOUIJaxbContext();
		this.eventProducer = new BusProvider_EventProducerNotifier(this.getConfiguration(), context);
	}

	public fr.mines_albi.nuclearcrisisevent.provider.ProvidebusDriverResponse providebusDriver(ProvidebusDriverRequest parameters)  {
		fr.mines_albi.nuclearcrisisevent.provider.ProvidebusDriverResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("providebusDriver" ,parameters);
		response = this.getTestImplementation().providebusDriver(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("busProvider", "busProviderPort", "providebusDriver", parameters, response, fr.mines_albi.nuclearcrisisevent.provider.ProvidebusDriverResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (fr.mines_albi.nuclearcrisisevent.provider.ProvidebusDriverResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("providebusDriver" ,parameters, response);
		return response;
	}


	public fr.mines_albi.nuclearcrisisevent.provider.ProvidebusResponse providebus(ProvidebusRequest parameters)  {
		fr.mines_albi.nuclearcrisisevent.provider.ProvidebusResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("providebus" ,parameters);
		response = this.getTestImplementation().providebus(parameters);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("busProvider", "busProviderPort", "providebus", parameters, response, fr.mines_albi.nuclearcrisisevent.provider.ProvidebusResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (fr.mines_albi.nuclearcrisisevent.provider.ProvidebusResponse) this.getGuiImplementation().getResponse();
		};		}
		eventProducer.sendEventBeforeSendResponse("providebus" ,parameters, response);
		return response;
	}



}
